'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
**/

var assert = require('assert');
var path = require('path');
var prettyBytes = require('pretty-bytes');
var workboxBuild = require('workbox-build');

var errors = require('./lib/errors');
var logger = require('./lib/logger');
var readConfig = require('./lib/read-config');
var runWizard = require('./lib/run-wizard');

module.exports = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(command, configFile) {
    var configPath, config, _ref2, size, count;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            assert(command, errors['missing-command-param']);

            _context.t0 = command;
            _context.next = _context.t0 === 'wizard' ? 4 : _context.t0 === 'generateSW' ? 7 : _context.t0 === 'injectManifest' ? 7 : 34;
            break;

          case 4:
            _context.next = 6;
            return runWizard();

          case 6:
            return _context.abrupt('break', 35);

          case 7:
            assert(configFile, errors['missing-config-file-param']);

            // TODO: Confirm that this works with Windows paths.
            configPath = path.resolve(process.cwd(), configFile);
            config = void 0;
            _context.prev = 10;

            config = readConfig(configPath);
            _context.next = 18;
            break;

          case 14:
            _context.prev = 14;
            _context.t1 = _context['catch'](10);

            logger.error(errors['invalid-common-js-module']);
            throw _context.t1;

          case 18:
            _context.prev = 18;
            _context.next = 21;
            return workboxBuild[command](config);

          case 21:
            _ref2 = _context.sent;
            size = _ref2.size;
            count = _ref2.count;

            logger.log(`The service worker was written to ${config.swDest}\n` + `${count} files will be precached, totalling ${prettyBytes(size)}.`);
            _context.next = 33;
            break;

          case 27:
            _context.prev = 27;
            _context.t2 = _context['catch'](18);

            if (!(typeof _context.t2.annotate === 'function')) {
              _context.next = 31;
              break;
            }

            throw new Error(`${errors['config-validation-failed']}\n${_context.t2.annotate()}`);

          case 31:
            logger.error(errors['workbox-build-runtime-error']);
            throw _context.t2;

          case 33:
            return _context.abrupt('break', 35);

          case 34:
            throw new Error(errors['unknown-command'] + ` ` + command);

          case 35:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[10, 14], [18, 27]]);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();